@@ -3,9 +3,10 @@
 // Distributed under the BSD License
 //
 
+#include <algorithm>
 #include <boost/algorithm/string.hpp>
 #include <boost/dll.hpp>
-#include <boost/filesystem.hpp>
+#include <filesystem>
 #include <rime/build_config.h>
 #include <rime/common.h>
 #include <rime/component.h>
@@ -13,15 +14,15 @@
 #include <rime/registry.h>
 #include <rime_api.h>
 
-namespace fs = boost::filesystem;
+namespace fs = std::filesystem;
 
 namespace rime {
 
 class PluginManager {
  public:
-  void LoadPlugins(fs::path plugins_dir);
+  void LoadPlugins(path plugins_dir);
 
-  static string plugin_name_of(fs::path plugin_file);
+  static string plugin_name_of(path plugin_file);
 
   static PluginManager& instance();
 
@@ -31,22 +32,22 @@ class PluginManager {
   map<string, boost::dll::shared_library> plugin_libs_;
 };
 
-void PluginManager::LoadPlugins(fs::path plugins_dir) {
+void PluginManager::LoadPlugins(path plugins_dir) {
   ModuleManager& mm = ModuleManager::instance();
   if (!fs::is_directory(plugins_dir)) {
     return;
   }
   LOG(INFO) << "loading plugins from " << plugins_dir;
   for (fs::directory_iterator iter(plugins_dir), end; iter != end; ++iter) {
-    fs::path plugin_file = iter->path();
+    path plugin_file = iter->path();
     if (plugin_file.extension() == boost::dll::shared_library::suffix()) {
       fs::file_status plugin_file_status = fs::status(plugin_file);
       if (fs::is_regular_file(plugin_file_status)) {
         DLOG(INFO) << "found plugin: " << plugin_file;
         string plugin_name = plugin_name_of(plugin_file);
         if (plugin_libs_.find(plugin_name) == plugin_libs_.end()) {
-          LOG(INFO) << "loading plugin '" << plugin_name
-                    << "' from " << plugin_file;
+          LOG(INFO) << "loading plugin '" << plugin_name << "' from "
+                    << plugin_file;
           try {
             auto plugin_lib = boost::dll::shared_library(plugin_file);
             plugin_libs_[plugin_name] = plugin_lib;
@@ -68,7 +69,7 @@ void PluginManager::LoadPlugins(fs::path plugins_dir) {
   }
 }
 
-string PluginManager::plugin_name_of(fs::path plugin_file) {
+string PluginManager::plugin_name_of(path plugin_file) {
   string name = plugin_file.stem().string();
   // remove prefix "(lib)rime-"
   if (boost::starts_with(name, "librime-")) {
@@ -78,7 +79,7 @@ string PluginManager::plugin_name_of(fs::path plugin_file) {
   }
   // replace dash with underscore, for the plugin name is part of the module
   // initializer function name.
-  boost::replace_all(name, "-", "_");
+  std::replace(name.begin(), name.end(), '-', '_');
   return name;
 }
 
@@ -92,8 +93,35 @@ PluginManager& PluginManager::instance() {
 
 }  // namespace rime
 
+#ifdef _WIN32
+// TODO: implement this when ready to support DLL plugins on Windows.
+inline static rime::path current_module_path() {
+  return rime::path{};
+}
+#else
+#include <dlfcn.h>
+
+inline static rime::path symbol_location(const void* symbol) {
+  Dl_info info;
+  // Some of the libc headers miss `const` in `dladdr(const void*, Dl_info*)`
+  const int res = dladdr(const_cast<void*>(symbol), &info);
+  if (res) {
+    return rime::path{info.dli_fname};
+  } else {
+    return rime::path{};
+  }
+}
+
+inline static rime::path current_module_path() {
+  void rime_require_module_plugins();
+  return symbol_location(
+      reinterpret_cast<const void*>(&rime_require_module_plugins));
+}
+#endif
+
 static void rime_plugins_initialize() {
-  rime::PluginManager::instance().LoadPlugins(RIME_PLUGINS_DIR);
+  rime::PluginManager::instance().LoadPlugins(
+      current_module_path().remove_filename() / RIME_PLUGINS_DIR);
 }
 
 static void rime_plugins_finalize() {}
