@@ -85,10 +85,11 @@ Preedit Composition::GetPreedit(const string& full_input,
   auto prompt = caret + GetPrompt();
   if (!prompt.empty()) {
     preedit.text.insert(preedit.caret_pos, prompt);
-    if (preedit.caret_pos < preedit.sel_end) {
+    if (preedit.caret_pos < preedit.sel_start) {
       preedit.sel_start += prompt.length();
+    }
+    if (preedit.caret_pos < preedit.sel_end) {
       preedit.sel_end += prompt.length();
-      preedit.caret_pos = preedit.sel_start;
     }
   }
   return preedit;
@@ -118,7 +119,7 @@ string Composition::GetCommitText() const {
   return result;
 }
 
-string Composition::GetScriptText() const {
+string Composition::GetScriptText(bool keep_selection) const {
   string result;
   size_t start = 0;
   size_t end = 0;
@@ -126,9 +127,12 @@ string Composition::GetScriptText() const {
     auto cand = seg.GetSelectedCandidate();
     start = end;
     end = cand ? cand->end() : seg.end;
-    if (cand && !cand->preedit().empty())
+    if (keep_selection && cand && !cand->text().empty() &&
+        seg.status >= Segment::kSelected)
+      result += cand->text();
+    else if (cand && !cand->preedit().empty())
       result += boost::erase_first_copy(cand->preedit(), "\t");
-    else
+    else if (!seg.HasTag("phony"))
       result += input_.substr(start, end - start);
   }
   if (input_.length() > end) {
