@@ -14,8 +14,7 @@ struct ConfigResource;
 
 class ConfigCompilerPlugin {
  public:
-  typedef bool Review(ConfigCompiler* compiler,
-                      an<ConfigResource> resource);
+  typedef bool Review(ConfigCompiler* compiler, an<ConfigResource> resource);
 
   virtual ~ConfigCompilerPlugin() = default;
 
@@ -58,7 +57,7 @@ struct ResourceType;
 
 class SaveOutputPlugin : public ConfigCompilerPlugin {
  public:
-  SaveOutputPlugin(const ResourceType& output_resource);
+  SaveOutputPlugin();
   virtual ~SaveOutputPlugin();
 
   Review ReviewCompileOutput;
