@@ -9,12 +9,11 @@
 #include <cstdlib>
 #include <sstream>
 #include <boost/algorithm/string.hpp>
-#include <boost/filesystem.hpp>
-#include <boost/lexical_cast.hpp>
 #include <rime/resource.h>
 #include <rime/schema.h>
 #include <rime/service.h>
 #include <rime/ticket.h>
+#include <rime/dict/db_pool_impl.h>
 #include <rime/dict/dict_settings.h>
 #include <rime/dict/reverse_lookup_dictionary.h>
 
@@ -28,18 +27,16 @@ const size_t kReverseFormatPrefixLen = sizeof(kReverseFormatPrefix) - 1;
 
 static const char* kStemKeySuffix = "\x1fstem";
 
-ReverseDb::ReverseDb(const string& file_name)
-    : MappedFile(file_name) {
-}
+ReverseDb::ReverseDb(const path& file_path) : MappedFile(file_path) {}
 
 bool ReverseDb::Load() {
-  LOG(INFO) << "loading reversedb: " << file_name();
+  LOG(INFO) << "loading reversedb: " << file_path();
 
   if (IsOpen())
     Close();
 
   if (!OpenReadOnly()) {
-    LOG(ERROR) << "Error opening reversedb '" << file_name() << "'.";
+    LOG(ERROR) << "Error opening reversedb '" << file_path() << "'.";
     return false;
   }
 
@@ -49,8 +46,8 @@ bool ReverseDb::Load() {
     Close();
     return false;
   }
-  if (strncmp(metadata_->format,
-              kReverseFormatPrefix, kReverseFormatPrefixLen)) {
+  if (strncmp(metadata_->format, kReverseFormatPrefix,
+              kReverseFormatPrefixLen)) {
     LOG(ERROR) << "invalid metadata.";
     Close();
     return false;
@@ -63,10 +60,10 @@ bool ReverseDb::Load() {
     return false;
   }
 
-  key_trie_.reset(new StringTable(metadata_->key_trie.get(),
-                                  metadata_->key_trie_size));
-  value_trie_.reset(new StringTable(metadata_->value_trie.get(),
-                                    metadata_->value_trie_size));
+  key_trie_.reset(
+      new StringTable(metadata_->key_trie.get(), metadata_->key_trie_size));
+  value_trie_.reset(
+      new StringTable(metadata_->value_trie.get(), metadata_->value_trie_size));
 
   return true;
 }
@@ -138,24 +135,23 @@ bool ReverseDb::Build(DictSettings* settings,
   const size_t kReservedSize = 1024;
   size_t key_trie_image_size = key_trie_builder.BinarySize();
   size_t value_trie_image_size = value_trie_builder.BinarySize();
-  size_t estimated_data_size = kReservedSize +
-      dict_settings.length() +
-      entry_count * sizeof(StringId) +
-      key_trie_image_size + value_trie_image_size;
+  size_t estimated_data_size = kReservedSize + dict_settings.length() +
+                               entry_count * sizeof(StringId) +
+                               key_trie_image_size + value_trie_image_size;
   if (!Create(estimated_data_size)) {
-    LOG(ERROR) << "Error creating prism file '" << file_name() << "'.";
+    LOG(ERROR) << "Error creating prism file '" << file_path() << "'.";
     return false;
   }
 
   // create metadata
   metadata_ = Allocate<reverse::Metadata>();
   if (!metadata_) {
-    LOG(ERROR) << "Error creating metadata in file '" << file_name() << "'.";
+    LOG(ERROR) << "Error creating metadata in file '" << file_path() << "'.";
     return false;
   }
   metadata_->dict_file_checksum = dict_file_checksum;
   if (!dict_settings.empty()) {
-    if(!CopyString(dict_settings, &metadata_->dict_settings)) {
+    if (!CopyString(dict_settings, &metadata_->dict_settings)) {
       LOG(ERROR) << "Error saving dict settings.";
       return false;
     }
@@ -198,7 +194,7 @@ bool ReverseDb::Build(DictSettings* settings,
 }
 
 bool ReverseDb::Save() {
-  LOG(INFO) << "saving reverse file: " << file_name();
+  LOG(INFO) << "saving reverse file: " << file_path();
   return ShrinkToFit();
 }
 
@@ -206,9 +202,7 @@ uint32_t ReverseDb::dict_file_checksum() const {
   return metadata_ ? metadata_->dict_file_checksum : 0;
 }
 
-ReverseLookupDictionary::ReverseLookupDictionary(an<ReverseDb> db)
-    : db_(db) {
-}
+ReverseLookupDictionary::ReverseLookupDictionary(an<ReverseDb> db) : db_(db) {}
 
 bool ReverseLookupDictionary::Load() {
   return db_ && (db_->IsOpen() || db_->Load());
@@ -217,11 +211,9 @@ bool ReverseLookupDictionary::Load() {
 bool ReverseLookupDictionary::ReverseLookup(const string& text,
                                             string* result) {
   return db_->Lookup(text, result);
-
 }
 
-bool ReverseLookupDictionary::LookupStems(const string& text,
-                                          string* result) {
+bool ReverseLookupDictionary::LookupStems(const string& text, string* result) {
   return db_->Lookup(text + kStemKeySuffix, result);
 }
 
@@ -239,34 +231,27 @@ an<DictSettings> ReverseLookupDictionary::GetDictSettings() {
   return settings;
 }
 
-static const ResourceType kReverseDbResourceType = {
-  "reverse_db", "", ".reverse.bin"
-};
+static const ResourceType kReverseDbResourceType = {"reverse_db", "",
+                                                    ".reverse.bin"};
 
 ReverseLookupDictionaryComponent::ReverseLookupDictionaryComponent()
-    : resource_resolver_(
+    : DbPool(the<ResourceResolver>(
           Service::instance().CreateDeployedResourceResolver(
-              kReverseDbResourceType)) {
-}
+              kReverseDbResourceType))) {}
 
-ReverseLookupDictionary*
-ReverseLookupDictionaryComponent::Create(const string& dict_name) {
-  auto db = db_pool_[dict_name].lock();
-  if (!db) {
-    auto file_path = resource_resolver_->ResolvePath(dict_name).string();
-    db = New<ReverseDb>(file_path);
-    db_pool_[dict_name] = db;
-  }
+ReverseLookupDictionary* ReverseLookupDictionaryComponent::Create(
+    const string& dict_name) {
+  auto db = GetDb(dict_name);
   return new ReverseLookupDictionary(db);
 };
 
-ReverseLookupDictionary*
-ReverseLookupDictionaryComponent::Create(const Ticket& ticket) {
-  if (!ticket.schema) return NULL;
+ReverseLookupDictionary* ReverseLookupDictionaryComponent::Create(
+    const Ticket& ticket) {
+  if (!ticket.schema)
+    return NULL;
   Config* config = ticket.schema->config();
   string dict_name;
-  if (!config->GetString(ticket.name_space + "/dictionary",
-                         &dict_name)) {
+  if (!config->GetString(ticket.name_space + "/dictionary", &dict_name)) {
     // missing!
     return NULL;
   }
