@@ -30,25 +30,40 @@ class ScriptTranslator : public Translator,
  public:
   ScriptTranslator(const Ticket& ticket);
 
-  virtual an<Translation> Query(const string& input, const Segment& segment);
-  virtual bool Memorize(const CommitEntry& commit_entry);
+  virtual an<Translation> Query(const string& input,
+                                const Segment& segment) override;
+  virtual bool Memorize(const CommitEntry& commit_entry) override;
+  virtual bool ProcessSegmentOnCommit(CommitEntry& commit_entry,
+                                      const Segment& seg) override;
 
   string FormatPreedit(const string& preedit);
   string Spell(const Code& code);
   string GetPrecedingText(size_t start) const;
+  bool UpdateElements(const CommitEntry& commit_entry);
+
+  bool ConcatenatePhrases(CommitEntry& commit_entry,
+                          const vector<an<Phrase>>& phrases);
+  bool SaveCommitEntry(CommitEntry& commit_entry);
 
   // options
   int max_homophones() const { return max_homophones_; }
   int spelling_hints() const { return spelling_hints_; }
   bool always_show_comments() const { return always_show_comments_; }
+  bool enable_word_completion() const { return enable_word_completion_; }
+  int max_word_length() const { return max_word_length_; }
+  int core_word_length() const;
 
  protected:
   int max_homophones_ = 1;
   int spelling_hints_ = 0;
+  int max_word_length_ = 0;
+  int core_word_length_ = 0;
   bool always_show_comments_ = false;
   bool enable_correction_ = false;
+  bool enable_word_completion_ = false;
   the<Corrector> corrector_;
   the<Poet> poet_;
+  vector<an<Phrase>> queue_;
 };
 
 }  // namespace rime
