@@ -13,8 +13,7 @@
 namespace rime {
 
 static inline size_t unistrlen(const string& text) {
-  return utf8::unchecked::distance(
-      text.c_str(), text.c_str() + text.length());
+  return utf8::unchecked::distance(text.c_str(), text.c_str() + text.length());
 }
 
 class SingleCharFirstTranslation : public PrefetchTranslation {
@@ -40,13 +39,13 @@ bool SingleCharFirstTranslation::Rearrange() {
   while (!translation_->exhausted()) {
     auto cand = translation_->Peek();
     auto phrase = As<Phrase>(Candidate::GetGenuineCandidate(cand));
-    if (!phrase || phrase->type() != "table" || phrase->type() != "user_table") {
+    if (!phrase ||
+        (phrase->type() != "table" && phrase->type() != "user_table")) {
       break;
     }
     if (unistrlen(cand->text()) == 1) {
       top.push_back(cand);
-    }
-    else {
+    } else {
       bottom.push_back(cand);
     }
     translation_->Next();
@@ -56,12 +55,10 @@ bool SingleCharFirstTranslation::Rearrange() {
   return !cache_.empty();
 }
 
-SingleCharFilter::SingleCharFilter(const Ticket& ticket)
-    : Filter(ticket) {
-}
+SingleCharFilter::SingleCharFilter(const Ticket& ticket) : Filter(ticket) {}
 
-an<Translation> SingleCharFilter::Apply(
-    an<Translation> translation, CandidateList* candidates) {
+an<Translation> SingleCharFilter::Apply(an<Translation> translation,
+                                        CandidateList* candidates) {
   return New<SingleCharFirstTranslation>(translation);
 }
 
