@@ -21,18 +21,18 @@ class DetectModifications : public DeploymentTask {
   bool Run(Deployer* deployer);
 
  protected:
-  vector<string> data_dirs_;
+  vector<path> data_dirs_;
 };
 
 // initialize/update installation.yaml
-class RIME_API InstallationUpdate : public DeploymentTask {
+class RIME_DLL InstallationUpdate : public DeploymentTask {
  public:
   InstallationUpdate(TaskInitializer arg = TaskInitializer()) {}
   bool Run(Deployer* deployer);
 };
 
 // update distributed config files and preset schemas
-class RIME_API WorkspaceUpdate : public DeploymentTask {
+class RIME_DLL WorkspaceUpdate : public DeploymentTask {
  public:
   WorkspaceUpdate(TaskInitializer arg = TaskInitializer()) {}
   bool Run(Deployer* deployer);
@@ -44,16 +44,15 @@ class RIME_API WorkspaceUpdate : public DeploymentTask {
 };
 
 // update a specific schema, build corresponding dictionary
-class RIME_API SchemaUpdate : public DeploymentTask {
+class RIME_DLL SchemaUpdate : public DeploymentTask {
  public:
-  explicit SchemaUpdate(const string& schema_file)
-      : schema_file_(schema_file) {}
+  explicit SchemaUpdate(const path& source_path) : source_path_(source_path) {}
   SchemaUpdate(TaskInitializer arg);
   bool Run(Deployer* deployer);
   void set_verbose(bool verbose) { verbose_ = verbose; }
 
  protected:
-  string schema_file_;
+  path source_path_;
   bool verbose_ = false;
 };
 
